Learn R Programming

duckdbfs (version 0.1.2)

duckdb_config: duckdb configuration

Description

duckdb configuration

Usage

duckdb_config(..., conn = cached_connection())

Value

the active duckdb connection, invisibly

Arguments

...

named argument of the parameters to set, see examples see all possible configuration options at https://duckdb.org/docs/sql/configuration.html

conn

A connection to a database.

Details

Note: in I/O bound tasks such as streaming data, it can be helpful to set thread parallelism significantly higher than available CPU cores.

See Also

duckdb_reset, duckdb_get_config

Examples

Run this code
if (FALSE) { # interactive()
duckdb_config(threads = 1, memory_limit = '10GB')
duckdb_get_config("threads")
duckdb_reset("threads")
}

Run the code above in your browser using DataLab