powered by
duckdb configuration
duckdb_config(..., conn = cached_connection())
the active duckdb connection, invisibly
named argument of the parameters to set, see examples see all possible configuration options at https://duckdb.org/docs/sql/configuration.html
A connection to a database.
Note: in I/O bound tasks such as streaming data, it can be helpful to set thread parallelism significantly higher than available CPU cores.
duckdb_reset, duckdb_get_config
if (FALSE) { # interactive() duckdb_config(threads = 1, memory_limit = '10GB') duckdb_get_config("threads") duckdb_reset("threads") }
Run the code above in your browser using DataLab