powered by
show duckdb extensions
duckdb_extensions(conn = cached_connection())
a data frame listing all available extensions, with boolean columns indicating which extensions are installed or loaded, and a description of each extension.
A connection to a database.
if (FALSE) { # interactive() duckdb_extensions() }
Run the code above in your browser using DataLab